package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

public final class ModuleExports implements Cloneable, Node {
   private final int exportsIndex;
   private final int exportsFlags;
   private final int exportsToCount;
   private final int[] exportsToIndex;

   ModuleExports(DataInput file) throws IOException {
      this.exportsIndex = file.readUnsignedShort();
      this.exportsFlags = file.readUnsignedShort();
      this.exportsToCount = file.readUnsignedShort();
      this.exportsToIndex = new int[this.exportsToCount];

      for(int i = 0; i < this.exportsToCount; ++i) {
         this.exportsToIndex[i] = file.readUnsignedShort();
      }

   }

   public void accept(Visitor v) {
      v.visitModuleExports(this);
   }

   public ModuleExports copy() {
      try {
         return (ModuleExports)this.clone();
      } catch (CloneNotSupportedException var2) {
         return null;
      }
   }

   public void dump(DataOutputStream file) throws IOException {
      file.writeShort(this.exportsIndex);
      file.writeShort(this.exportsFlags);
      file.writeShort(this.exportsToCount);
      int[] var2 = this.exportsToIndex;
      int var3 = var2.length;

      for(int var4 = 0; var4 < var3; ++var4) {
         int entry = var2[var4];
         file.writeShort(entry);
      }

   }

   public String toString() {
      return "exports(" + this.exportsIndex + ", " + this.exportsFlags + ", " + this.exportsToCount + ", ...)";
   }

   public String toString(ConstantPool constantPool) {
      StringBuilder buf = new StringBuilder();
      String packageName = constantPool.constantToString(this.exportsIndex, (byte)20);
      buf.append(Utility.compactClassName(packageName, false));
      buf.append(", ").append(String.format("%04x", this.exportsFlags));
      buf.append(", to(").append(this.exportsToCount).append("):\n");
      int[] var4 = this.exportsToIndex;
      int var5 = var4.length;

      for(int var6 = 0; var6 < var5; ++var6) {
         int index = var4[var6];
         String moduleName = constantPool.getConstantString(index, (byte)19);
         buf.append("      ").append(Utility.compactClassName(moduleName, false)).append("\n");
      }

      return buf.substring(0, buf.length() - 1);
   }
}
